<?php

namespace App\Jobs;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use App\Models\EmailService;
use App\Models\EmailServiceMetric;
use Carbon\Carbon;

class UpdateEmailMetrics implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    public function handle()
    {
        $today = Carbon::now()->startOfDay();

        EmailService::each(function ($service) use ($today) {
            $todayEmails = $service->emailQueue()
                ->whereDate('created_at', $today)
                ->get();

            // Calcula métricas
            $sent = $todayEmails->where('status', 'sent')->count();
            $failed = $todayEmails->where('status', 'failed')->count();
            
            // Calcula tempo médio de envio
            $sentEmails = $todayEmails->where('status', 'sent')->whereNotNull('sent_at');
            
            $avgTime = 0;
            if ($sentEmails->count() > 0) {
                $totalTime = $sentEmails->sum(function ($email) {
                    return $email->created_at->diffInSeconds($email->sent_at, false);
                });
                $avgTime = abs($totalTime / $sentEmails->count());
            }

            // Atualiza ou cria métricas
            EmailServiceMetric::updateOrCreate(
                [
                    'email_service_id' => $service->id,
                    'period' => 'daily',
                    'date' => $today
                ],
                [
                    'emails_sent' => $sent,
                    'emails_failed' => $failed,
                    'average_sending_time' => $avgTime
                ]
            );
        });
    }
} 